import { useEditor } from "@/modules/editor";
import { queenApi } from "queenjs";
import { string , object} from "vue-types";
import { useCompData } from ".";
import { createUIComp } from "../../defines/createUIComp";

export const Component = createUIComp({
  props: {
    compId: string(),
    value: object<{url:string, x:number, y:number, s:number}>(),
  },
  emits: ["update:value"],
  setup(props, { emit }) {
    const comp = props.compId ? useCompData(props.compId) : null;
    const { store, controls } = useEditor();
    async function changeVal() {
      
      const url = await controls.pickCtrl.pickOneImage();
      if (!url) return;
      
      if (comp) {
        comp.value.url = url;
        comp.value.x = 0;
        comp.value.y = 0;
        comp.value.s = 1;
      } else {

        emit("update:value", {url, x: 0, y: 0, s: 1});
      }
    }

    return () => {

      const value = comp?.value || props.value;
      const scale =  value?.s || 1;
      const ox = value?.x || 0;
      const oy = value?.y || 0;
      const objFit =  (scale + "" == "1") && (ox + "") == "0" &&  (oy + "") == "0" ? "object-cover" : "object-contain"
      
      return (
        <img
          class={"w-1/1 h-1/1 " + objFit}
          style={{transform: `scale(${scale}) translate(${ox}%,${oy}%)`}}
          src={value?.url}
          onDblclick={store.isEditMode ? changeVal : undefined}
        />
      )
    }
  },
});
